.. _all-salt.beacons:

==============
beacon modules
==============

.. currentmodule:: salt.beacons

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    adb
    avahi_announce
    bonjour_announce
    btmp
    diskusage
    glxinfo
    haproxy
    inotify
    journald
    load
    memusage
    network_info
    network_settings
    pkg
    proxy_example
    ps
    salt_proxy
    service
    sh
    status
    twilio_txt_msg
    wtmp
